pub struct MediaEntity { /* private fields */ }Expand description
A media entity is a title with optional episode and rating records.
A media entity makes it convenient to deal with the complete information
of an IMDb media record. This is the default value returned by search
routines such as what the Searcher provides, and
can also be cheaply constructed by an Index given a
Title or an IMDb ID.
Implementations
Sourceimpl MediaEntity
impl MediaEntity